എല്ലിപ്സിസ് = Ellipsis
തെറ്റായ = False
ഒന്നുമില്ല = None
നടപ്പിലാക്കാത്ത = NotImplemented
ശരി = True
__നിർമാണ_ക്ലാസ്__ = __build_class__
__പ്രമാണം__ = __doc__
__ഇറക്കുമതി__ = __import__
__ലോഡർ__ = __loader__
__പേര്__ = __name__
__കെട്ട്__ = __package__
__വിവരണം__ = __spec__
എബിഎസ് = abs
എല്ലാം = all
എന്തെങ്കിലും = any
ആസ്കി = ascii
ആകുന്നു = bin
ബൂള് = bool
നിരതനസ്തലം = breakpoint
ബ്യ്തെഅര്രയ് = bytearray
ബൈറ്റുകൾ = bytes
വിളികാനപറ്റന = callable
അക്ഷരം = chr
ക്ലാസ്_മെഥെട് = classmethod
കംപൈല് = compile
സങ്കീർണ്ണമായ = complex
പകർപ്പവകാശ = copyright
ക്രെഡിറ്റുകൾ = credits
ഗുണം_ഒഴിവാക്കുക = delattr
നിഘണ്ഡു = dict
നാമാവലിപ്പട്ടിക = dir
ദിവ്മൊദ് = divmod
നിരത്തുക = enumerate
വില = eval
ചെയ്യൂ = exec
പുറത്ത് = exit
അരിപ്പ = filter
ഒഴുകുക = float
ഫോർമാറ്റ് = format
ഉറഞ്ഞഗണം = frozenset
ഗെതത്ത്ര് = getattr
ആഗോള = globals
ഹ്സത്ത്ര് = hasattr
ഹാഷ് = hash
സഹായിക്കൂ = help
ഹെക്സ് = hex
ഐഡി = id
ഇൻപുട്ട് = input
പൂർണ്ണസംഖ്യ = int
സന്ദര്ഭമാണൊ = isinstance
ഉപക്ലാസ്സണൊ = issubclass
പ്രക്രിയ = iter
നീളം = len
ലൈസൻസ് = license
പട്ടിക = list
പ്രദേശവാസികൾ = locals
ഭൂപടം = map
പരമാവധി = max
മെമൊര്യ്വിഎവ് = memoryview
കുറഞ്ഞ = min
അടുത്തത് = next
വസ്തു = object
ഒകട = oct
തുറക്കുക = open
ക്രമം = ord
മൊളില് = pow
അച്ചടിക്കുക = print
സ്വഭാവം = property
ഉപേക്ഷിക്കു = quit
ശ്രേണി = range
ചിത്രീകരിക്കുക = repr
വിപരീത = reversed
വട്ടം = round
ഗണം = set
സെതത്ത്ര് = setattr
പൂള് = slice
അടുക്കിയ = sorted
നിശ്ചലമെഥൊദ് = staticmethod
നാട = str
മൊത്തം = sum
സൂപ്പർ = super
നിര = tuple
തരം = type
വിവിധം = vars
പൂട്ടു = zip


keywords = {
    "\bഉം\b" "and",
    "\bപോലെ\b" "as",
    "\bഉറപ്പിക്കുക\b" "assert",
    "\bഅസിൻക്\b" "async",
    "\bകാത്തിരിക്കുക\b" "await",
    "\bപൊട്ടിക്കുക\b" "break",
    "\bക്ലാസ്സ്\b" "class",
    "\bതുടരുക\b" "continue",
    "\bനിര്‍വചനം\b" "def",
    "\bകളയുക\b" "del",
    "\bഅല്ലെങ്കിലെങ്കില്‍\b" "elif",
    "\bഅല്ലെങ്കില്‍\b" "else",
    "\bഅസാധാരണം\b" "except",
    "\bഅവസാനമായി\b" "finally",
    "\bകറങ്ങട്ടെ\b" "for",
    "\bഇവിടുന്ന്\b" "from",
    "\bആഗോള\b" "global",
    "\bഎങ്കില്‍\b" "if",
    "\bഇറക്കുമതി\b" "import",
    "\bൽ\b" "in",
    "\bആണ്\b" "is",
    "\bലാംഡ\b" "lambda",
    "\bനാടനല്ലാത്ത\b" "nonlocal",
    "\bഅല്ല\b" "not",
    "\bഅഥവാ\b" "or",
    "\bകടന്ന്പോ\b" "pass",
    "\bഉയര്ത്തുക\b" "raise",
    "\bമടക്കം\b" "return",
    "\bശ്രമിച്ചുനോക്കൂ\b" "try",
    "\bഇതുവരെ\b" "while",
    "\bകൂടെ\b" "with",
    "\bഫലം\b" "yield"
}
